# This spec file is derived from RHEL 9.0 GA package. They should be kept in sync over time.
# Upstream: https://gitlab.com/redhat/centos-stream/rpms/gtksourceview4
%global rhel_name gtksourceview4
%global rhel_release 3
%global epel_release 1
%global _debugsource_template %{nil}

%global glib_version 2.48
%global gtk_version 3.22

Name:           gtksourceview4-epel
Version:        4.8.1
Release:        0.%{rhel_release}%{?dist}.%{epel_release}
Summary:        Source code editing widget

License:        LGPLv2+
URL:            https://wiki.gnome.org/Projects/GtkSourceView
Source0:        https://download.gnome.org/sources/gtksourceview/4.8/gtksourceview-%{version}.tar.xz

# EPEL-only patch to avoid race condition build failures related to gtksourceview-gresources.h
Patch9000:      gtksourceview4-epel-4.8.1-gresources.patch

BuildRequires:  gcc
BuildRequires:  gettext
BuildRequires:  gtk-doc
BuildRequires:  itstool
BuildRequires:  meson
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gladeui-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= %{glib_version}
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= %{gtk_version}
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(pango)
BuildRequires:  vala

Requires: glib2%{?_isa} >= %{glib_version}
Requires: gtk3%{?_isa} >= %{gtk_version}

%description
GtkSourceView is a GNOME library that extends GtkTextView, the standard GTK+
widget for multiline text editing. GtkSourceView adds support for syntax
highlighting, undo/redo, file loading and saving, search and replace, a
completion system, printing, displaying line numbers, and other features
typical of a source code editor.

This package contains version 4 of GtkSourceView.

%package -n     %{rhel_name}-devel
Summary:        Development files for %{rhel_name}
Requires:       %{rhel_name}%{?_isa} = %{version}

%description -n %{rhel_name}-devel
The %{rhel_name}-devel package contains libraries and header files for
developing applications that use %{rhel_name}.

%prep
%autosetup -n gtksourceview-%{version} -p1

%build
%meson -Dgtk_doc=true -Dglade_catalog=true -Dinstall_tests=true
%meson_build

%install
%meson_install

%find_lang gtksourceview-4

# Remove files shipped in RHEL 9
rm -rf $RPM_BUILD_ROOT%{_libdir}/{girepository-1.0/,libgtksourceview-4.so.0*}
rm -rf $RPM_BUILD_ROOT%{_datadir}/{gtksourceview-4,locale}/
rm -rf $RPM_BUILD_ROOT{%{_libexecdir},%{_datadir}}/installed-tests/

%files -n %{rhel_name}-devel
%{_includedir}/gtksourceview-4/
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libgtksourceview-4.so
%dir %{_datadir}/gir-1.0
%{_datadir}/gir-1.0/GtkSource-4.gir
%dir %{_datadir}/glade
%dir %{_datadir}/glade/catalogs
%{_datadir}/glade/catalogs/gtksourceview.xml
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/*
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/gtksourceview-4.deps
%{_datadir}/vala/vapi/gtksourceview-4.vapi

%changelog
* Wed Jun 29 2022 Robert Scheck <robert@fedoraproject.org> - 4.8.1-0.3.el9.1
- Transformed gtksourceview4-4.8.1-3.el9 into gtksourceview4-epel to
  achieve the missing gtksourceview4-devel package for EPEL 9 until it's
  available in RHEL
  Related: rhbz#2012355

* Mon Aug 09 2021 Mohan Boddu <mboddu@redhat.com> - 4.8.1-3
- Rebuilt for IMA sigs, glibc 2.34, aarch64 flags
  Related: rhbz#1991688

* Fri Apr 16 2021 Mohan Boddu <mboddu@redhat.com> - 4.8.1-2
- Rebuilt for RHEL 9 BETA on Apr 15th 2021. Related: rhbz#1947937

* Tue Mar 02 2021 Kalev Lember <klember@redhat.com> - 4.8.1-1
- Update to 4.8.1

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 4.8.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Sat Sep 12 2020 Kalev Lember <klember@redhat.com> - 4.8.0-1
- Update to 4.8.0

* Mon Aug 17 2020 Kalev Lember <klember@redhat.com> - 4.7.90-1
- Update to 4.7.90

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.6.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Mon Jul 20 2020 Kalev Lember <klember@redhat.com> - 4.6.1-1
- Update to 4.6.1

* Sat Mar 07 2020 Kalev Lember <klember@redhat.com> - 4.6.0-1
- Update to 4.6.0

* Mon Feb 17 2020 Kalev Lember <klember@redhat.com> - 4.5.91-1
- Update to 4.5.91

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.4.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Tue Sep 10 2019 Kalev Lember <klember@redhat.com> - 4.4.0-1
- Update to 4.4.0

* Wed Sep 04 2019 Kalev Lember <klember@redhat.com> - 4.3.92-1
- Update to 4.3.92

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 4.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon Apr 29 2019 Phil Wyett <philwyett@kathenas.org> - 4.3.1-1
- Update to 4.3.1
- Convert to meson

* Sat Mar 16 2019 Kalev Lember <klember@redhat.com> - 4.2.0-1
- Update to 4.2.0

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Sep 07 2018 Kalev Lember <klember@redhat.com> - 4.0.3-2
- Rebuilt against fixed atk (#1626575)

* Fri Sep 07 2018 Pete Walter <pwalter@fedoraproject.org> - 4.0.3-1
- Initial packaging of GtkSourceView 4
